aboutsummaryrefslogtreecommitdiffhomepage
path: root/libmpv/render.h
diff options
context:
space:
mode:
Diffstat (limited to 'libmpv/render.h')
-rw-r--r--libmpv/render.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/libmpv/render.h b/libmpv/render.h
index 253b2b43f9..304a21a932 100644
--- a/libmpv/render.h
+++ b/libmpv/render.h
@@ -283,14 +283,20 @@ typedef enum mpv_render_param_type {
*/
MPV_RENDER_PARAM_DRM_DISPLAY = 14,
/**
* DRM osd size, contains osd dimensions.
* Valid for mpv_render_context_create().
- * Type : struct mpv_opengl_drm_osd_size*
+ * Type : struct mpv_opengl_drm_draw_surface_size*
*/
- MPV_RENDER_PARAM_DRM_OSD_SIZE = 15,
+ MPV_RENDER_PARAM_DRM_DRAW_SURFACE_SIZE = 15,
} mpv_render_param_type;
/**
+ * For backwards compatibility with the old naming of
+ * MPV_RENDER_PARAM_DRM_DRAW_SURFACE_SIZE
+ */
+#define MPV_RENDER_PARAM_DRM_OSD_SIZE MPV_RENDER_PARAM_DRM_DRAW_SURFACE_SIZE
+
+/**
* Used to pass arbitrary parameters to some mpv_render_* functions. The
* meaning of the data parameter is determined by the type, and each
* MPV_RENDER_PARAM_* documents what type the value must point to.
@@ -283,14 +283,20 @@ typedef enum mpv_render_param_type {
MPV_RENDER_PARAM_DRM_DISPLAY = 14,
/**
- * DRM osd size, contains osd dimensions.
+ * DRM draw surface size, contains draw surface dimensions.
* Valid for mpv_render_context_create().